summaryrefslogtreecommitdiff
path: root/src/rc/rc.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/rc/rc.c')
-rw-r--r--src/rc/rc.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/rc/rc.c b/src/rc/rc.c
index 183c23c..e1b7ac3 100644
--- a/src/rc/rc.c
+++ b/src/rc/rc.c
@@ -289,8 +289,8 @@ static void sulogin (bool cont)
#ifdef __linux__
char *e = getenv ("RC_SYS");
- /* VPS systems cannot do a sulogin */
- if (e && strcmp (e, "VPS") == 0) {
+ /* VSERVER and OPENVZ systems cannot do a sulogin */
+ if (e && (strcmp (e, "VSERVER") == 0 || strcmp (e, "OPENVZ") == 0) {
execl ("/sbin/halt", "/sbin/halt", "-f", (char *) NULL);
eerrorx ("%s: unable to exec `/sbin/halt': %s", applet, strerror (errno));
}